
ESP32 Machine Emulator
======================

Title are underlined with equals signs too
==========================================

ESP32 Machine Emulator
======================

Subtitles with dashes
---------------------

You can  put text in *italic* or in **bold**, you can "mark" text as
code with double backquote ``print()``.

Lists are as simple as in Markdown:

- First item
- Second item
    - Sub item

or

* First item
* Second item
    * Sub item

Tables are really easy to write:

=========== ========
Country     Capital
=========== ========
France      Paris
Japan       Tokyo
=========== ========

More complex tables can be done easily (merged columns and/or rows)
but I suggest you to
read the complete doc for this :)

There are multiple ways to make links:

- By adding an underscore after a word : Github_ and by adding the target
  URL after the text (this way has the advantage to not insert unnecessary
  URLs inside readable text).

- By typing a full comprehensible URL : https://github.com/ (will be automatically converted to a link)
- By making a more Markdown-like link: `Github <https://github.com/>`_ .
